# **PowerJira**
*A succinct local jira control plane*

<br />

## **Welcome to PowerJira!**
Hello world.

<br />

### **Table of Contents** 📖
<hr>

  - [Welcome](#welcome-to-powerjira)
  - [**Get Started**](#get-started-)
  - [Usage](#usage-)
  - [Technologies](#technologies-)
  - [Contribute](#Contribute-)
  - [Acknowledgements](#acknowledgements-)
  - [License/Stats/Author](#license-stats-author-)

<br />

## **Get Started 🚀**
<hr>

Hello world.

<br />

## **Usage ⚙**
<hr>

Hello world.

<br />

## **Technologies 🧰**
<hr>

  - [flip.js](https://google.com)
  - [flop.js](https://google.com)
  - [flap.js](https://google.com)

<br />

## **Contribute 🤝**
<hr>

Hello world.

<br />

## **Acknowledgements 💙**
<hr>

Hello world.

<br />

## **License, Stats, Author 📜**
<hr>

<img align="right" alt="example image tag" src="https://i.imgur.com/jtNwEWu.png" width="200" />

<!-- badge cluster -->

[SHIELD](https://shields.io/)

<!-- / -->
See [License](https://google.com) for the full license text.

This repository was authored by *Isaac Yep*.

[Back to Table of Contents](#table-of-contents-)